"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def copy(
    hub,
    ctx,
    source_product_arn: str,
    idempotency_token: str,
    accept_language: str = None,
    target_product_id: str = None,
    target_product_name: str = None,
    source_provisioning_artifact_identifiers: List = None,
    copy_options: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Copies the specified source product to the specified target product or a new product. You can copy a product to the same account or another account. You can copy a product to the same region or another region. This operation is performed asynchronously. To track the progress of the operation, use DescribeCopyProductStatus.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        source_product_arn(str): The Amazon Resource Name (ARN) of the source product.
        target_product_id(str, optional): The identifier of the target product. By default, a new product is created. Defaults to None.
        target_product_name(str, optional): A name for the target product. The default is the name of the source product. Defaults to None.
        source_provisioning_artifact_identifiers(List, optional): The identifiers of the provisioning artifacts (also known as versions) of the product to copy. By default, all provisioning artifacts are copied. Defaults to None.
        copy_options(List, optional): The copy options. If the value is CopyTags, the tags from the source product are copied to the target product. Defaults to None.
        idempotency_token(str):  A unique identifier that you provide to ensure idempotency. If multiple requests differ only by the idempotency token, the same response is returned for each repeated request. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.product.init.copy(
                ctx, source_product_arn=value, idempotency_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.product.init.copy source_product_arn=value, idempotency_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="copy_product",
        op_kwargs={
            "AcceptLanguage": accept_language,
            "SourceProductArn": source_product_arn,
            "TargetProductId": target_product_id,
            "TargetProductName": target_product_name,
            "SourceProvisioningArtifactIdentifiers": source_provisioning_artifact_identifiers,
            "CopyOptions": copy_options,
            "IdempotencyToken": idempotency_token,
        },
    )


async def create(
    hub,
    ctx,
    name: str,
    owner: str,
    product_type: str,
    provisioning_artifact_parameters: Dict,
    idempotency_token: str,
    accept_language: str = None,
    description: str = None,
    distributor: str = None,
    support_description: str = None,
    support_email: str = None,
    support_url: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a product. A delegated admin is authorized to invoke this command. The user or role that performs this operation must have the cloudformation:GetTemplate IAM policy permission. This policy permission is required when using the ImportFromPhysicalId template source in the information data section.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        name(str): The name of the product.
        owner(str): The owner of the product.
        description(str, optional): The description of the product. Defaults to None.
        distributor(str, optional): The distributor of the product. Defaults to None.
        support_description(str, optional): The support information about the product. Defaults to None.
        support_email(str, optional): The contact email for product support. Defaults to None.
        support_url(str, optional): The contact URL for product support.  ^https?:\/\// / is the pattern used to validate SupportUrl. Defaults to None.
        product_type(str): The type of product.
        tags(List, optional): One or more tags. Defaults to None.
        provisioning_artifact_parameters(Dict): The configuration of the provisioning artifact. .
        idempotency_token(str): A unique identifier that you provide to ensure idempotency. If multiple requests differ only by the idempotency token, the same response is returned for each repeated request.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.product.init.create(
                ctx,
                name=value,
                owner=value,
                product_type=value,
                provisioning_artifact_parameters=value,
                idempotency_token=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.product.init.create name=value, owner=value, product_type=value, provisioning_artifact_parameters=value, idempotency_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="create_product",
        op_kwargs={
            "AcceptLanguage": accept_language,
            "Name": name,
            "Owner": owner,
            "Description": description,
            "Distributor": distributor,
            "SupportDescription": support_description,
            "SupportEmail": support_email,
            "SupportUrl": support_url,
            "ProductType": product_type,
            "Tags": tags,
            "ProvisioningArtifactParameters": provisioning_artifact_parameters,
            "IdempotencyToken": idempotency_token,
        },
    )


async def delete(hub, ctx, id_: str, accept_language: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified product. You cannot delete a product if it was shared with you or is associated with a portfolio. A delegated admin is authorized to invoke this command.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        id_(str): The product identifier.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.product.init.delete(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.product.init.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="delete_product",
        op_kwargs={"AcceptLanguage": accept_language, "Id": id_},
    )


async def describe(
    hub, ctx, accept_language: str = None, id_: str = None, name: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the specified product.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        id_(str, optional): The product identifier. Defaults to None.
        name(str, optional): The product name. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.product.init.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.product.init.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="describe_product",
        op_kwargs={"AcceptLanguage": accept_language, "Id": id_, "Name": name},
    )


async def provision(
    hub,
    ctx,
    provisioned_product_name: str,
    provision_token: str,
    accept_language: str = None,
    product_id: str = None,
    product_name: str = None,
    provisioning_artifact_id: str = None,
    provisioning_artifact_name: str = None,
    path_id: str = None,
    path_name: str = None,
    provisioning_parameters: List = None,
    provisioning_preferences: Dict = None,
    tags: List = None,
    notification_arns: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Provisions the specified product. A provisioned product is a resourced instance of a product. For example, provisioning a product based on a CloudFormation template launches a CloudFormation stack and its underlying resources. You can check the status of this request using DescribeRecord. If the request contains a tag key with an empty list of values, there is a tag conflict for that key. Do not include conflicted keys as tags, or this causes the error "Parameter validation failed: Missing required parameter in Tags[N]:Value".

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        product_id(str, optional): The product identifier. You must provide the name or ID, but not both. Defaults to None.
        product_name(str, optional): The name of the product. You must provide the name or ID, but not both. Defaults to None.
        provisioning_artifact_id(str, optional): The identifier of the provisioning artifact. You must provide the name or ID, but not both. Defaults to None.
        provisioning_artifact_name(str, optional): The name of the provisioning artifact. You must provide the name or ID, but not both. Defaults to None.
        path_id(str, optional): The path identifier of the product. This value is optional if the product has a default path, and required if the product has more than one path. To list the paths for a product, use ListLaunchPaths. You must provide the name or ID, but not both. Defaults to None.
        path_name(str, optional): The name of the path. You must provide the name or ID, but not both. Defaults to None.
        provisioned_product_name(str): A user-friendly name for the provisioned product. This value must be unique for the AWS account and cannot be updated after the product is provisioned.
        provisioning_parameters(List, optional): Parameters specified by the administrator that are required for provisioning the product. Defaults to None.
        provisioning_preferences(Dict, optional): An object that contains information about the provisioning preferences for a stack set. Defaults to None.
        tags(List, optional): One or more tags. Defaults to None.
        notification_arns(List, optional): Passed to CloudFormation. The SNS topic ARNs to which to publish stack-related events. Defaults to None.
        provision_token(str): An idempotency token that uniquely identifies the provisioning request.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.product.init.provision(
                ctx, provisioned_product_name=value, provision_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.product.init.provision provisioned_product_name=value, provision_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="provision_product",
        op_kwargs={
            "AcceptLanguage": accept_language,
            "ProductId": product_id,
            "ProductName": product_name,
            "ProvisioningArtifactId": provisioning_artifact_id,
            "ProvisioningArtifactName": provisioning_artifact_name,
            "PathId": path_id,
            "PathName": path_name,
            "ProvisionedProductName": provisioned_product_name,
            "ProvisioningParameters": provisioning_parameters,
            "ProvisioningPreferences": provisioning_preferences,
            "Tags": tags,
            "NotificationArns": notification_arns,
            "ProvisionToken": provision_token,
        },
    )


async def search(
    hub,
    ctx,
    accept_language: str = None,
    filters: Dict = None,
    page_size: int = None,
    sort_by: str = None,
    sort_order: str = None,
    page_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the products to which the caller has access.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        filters(Dict, optional): The search filters. If no search filters are specified, the output includes all products to which the caller has access. Defaults to None.
        page_size(int, optional): The maximum number of items to return with this call. Defaults to None.
        sort_by(str, optional): The sort field. If no value is specified, the results are not sorted. Defaults to None.
        sort_order(str, optional): The sort order. If no value is specified, the results are not sorted. Defaults to None.
        page_token(str, optional): The page token for the next set of results. To retrieve the first set of results, use null. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.product.init.search(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.product.init.search
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="search_products",
        op_kwargs={
            "AcceptLanguage": accept_language,
            "Filters": filters,
            "PageSize": page_size,
            "SortBy": sort_by,
            "SortOrder": sort_order,
            "PageToken": page_token,
        },
    )


async def update(
    hub,
    ctx,
    id_: str,
    accept_language: str = None,
    name: str = None,
    owner: str = None,
    description: str = None,
    distributor: str = None,
    support_description: str = None,
    support_email: str = None,
    support_url: str = None,
    add_tags: List = None,
    remove_tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified product.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        id_(str): The product identifier.
        name(str, optional): The updated product name. Defaults to None.
        owner(str, optional): The updated owner of the product. Defaults to None.
        description(str, optional): The updated description of the product. Defaults to None.
        distributor(str, optional): The updated distributor of the product. Defaults to None.
        support_description(str, optional): The updated support description for the product. Defaults to None.
        support_email(str, optional): The updated support email for the product. Defaults to None.
        support_url(str, optional): The updated support URL for the product. Defaults to None.
        add_tags(List, optional): The tags to add to the product. Defaults to None.
        remove_tags(List, optional): The tags to remove from the product. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.product.init.update(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.product.init.update id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="update_product",
        op_kwargs={
            "AcceptLanguage": accept_language,
            "Id": id_,
            "Name": name,
            "Owner": owner,
            "Description": description,
            "Distributor": distributor,
            "SupportDescription": support_description,
            "SupportEmail": support_email,
            "SupportUrl": support_url,
            "AddTags": add_tags,
            "RemoveTags": remove_tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(hub, ctx, anomaly_monitor: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new cost anomaly detection monitor with the requested type and monitor specification.

    Args:
        anomaly_monitor(Dict):  The cost anomaly detection monitor object that you want to create.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ce.anomaly.monitor.create(ctx, anomaly_monitor=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ce.anomaly.monitor.create anomaly_monitor=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ce",
        operation="create_anomaly_monitor",
        op_kwargs={"AnomalyMonitor": anomaly_monitor},
    )


async def delete(hub, ctx, monitor_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a cost anomaly monitor.

    Args:
        monitor_arn(str):  The unique identifier of the cost anomaly monitor that you want to delete. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ce.anomaly.monitor.delete(ctx, monitor_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ce.anomaly.monitor.delete monitor_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ce",
        operation="delete_anomaly_monitor",
        op_kwargs={"MonitorArn": monitor_arn},
    )


async def get_all(
    hub,
    ctx,
    monitor_arn_list: List = None,
    next_page_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the cost anomaly monitor definitions for your account. You can filter using a list of cost anomaly monitor Amazon Resource Names (ARNs).

    Args:
        monitor_arn_list(List, optional):  A list of cost anomaly monitor ARNs. . Defaults to None.
        next_page_token(str, optional):  The token to retrieve the next set of results. AWS provides the token when the response from a previous call has more results than the maximum page size. . Defaults to None.
        max_results(int, optional):  The number of entries a paginated response contains. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ce.anomaly.monitor.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ce.anomaly.monitor.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ce",
        operation="get_anomaly_monitors",
        op_kwargs={
            "MonitorArnList": monitor_arn_list,
            "NextPageToken": next_page_token,
            "MaxResults": max_results,
        },
    )


async def update(hub, ctx, monitor_arn: str, monitor_name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing cost anomaly monitor. The changes made are applied going forward, and does not change anomalies detected in the past.

    Args:
        monitor_arn(str):  Cost anomaly monitor Amazon Resource Names (ARNs). .
        monitor_name(str, optional):  The new name for the cost anomaly monitor. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ce.anomaly.monitor.update(ctx, monitor_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ce.anomaly.monitor.update monitor_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ce",
        operation="update_anomaly_monitor",
        op_kwargs={"MonitorArn": monitor_arn, "MonitorName": monitor_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def send(
    hub, ctx, instance_id: str, ssh_public_key: str, serial_port: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Pushes an SSH public key to the specified EC2 instance. The key remains for 60 seconds, which gives you 60 seconds to establish a serial console connection to the instance using SSH. For more information, see EC2 Serial Console in the Amazon EC2 User Guide.

    Args:
        instance_id(str): The ID of the EC2 instance.
        serial_port(int, optional): The serial port of the EC2 instance. Currently only port 0 is supported. Default: 0. Defaults to None.
        ssh_public_key(str): The public key material. To use the public key, you must have the matching private key. For information about the supported key formats and lengths, see Requirements for key pairs in the Amazon EC2 User Guide.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2_instance_connect.serial_console_ssh_public_key.send(
                ctx, instance_id=value, ssh_public_key=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2_instance_connect.serial_console_ssh_public_key.send instance_id=value, ssh_public_key=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2-instance-connect",
        operation="send_serial_console_ssh_public_key",
        op_kwargs={
            "InstanceId": instance_id,
            "SerialPort": serial_port,
            "SSHPublicKey": ssh_public_key,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Adds one or more key-value tags to an Amazon Lookout for Vision model. For more information, see Tagging a model in the Amazon Lookout for Vision Developer Guide.  This operation requires permissions to perform the lookoutvision:TagResource operation.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the model to assign the tags.
        tags(List): The key-value tags to assign to the model.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutvision.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutvision.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutvision",
        operation="tag_resource",
        op_kwargs={"ResourceArn": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes one or more tags from an Amazon Lookout for Vision model. For more information, see Tagging a model in the Amazon Lookout for Vision Developer Guide.  This operation requires permissions to perform the lookoutvision:UntagResource operation.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the model from which you want to remove tags. .
        tag_keys(List): A list of the keys of the tags that you want to remove.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutvision.resource.untag(
                ctx, resource_arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutvision.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutvision",
        operation="untag_resource",
        op_kwargs={"ResourceArn": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(
    hub,
    ctx,
    relational_database_name: str,
    metric_name: str,
    period: int,
    start_time: str,
    end_time: str,
    unit: str,
    statistics: List,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the data points of the specified metric for a database in Amazon Lightsail. Metrics report the utilization of your resources, and the error counts generated by them. Monitor and collect metric data regularly to maintain the reliability, availability, and performance of your resources.

    Args:
        relational_database_name(str): The name of your database from which to get metric data.
        metric_name(str): The metric for which you want to return information. Valid relational database metric names are listed below, along with the most useful statistics to include in your request, and the published unit value. All relational database metric data is available in 1-minute (60 seconds) granularity.     CPUUtilization  - The percentage of CPU utilization currently in use on the database.  Statistics: The most useful statistics are Maximum and Average.  Unit: The published unit is Percent.     DatabaseConnections  - The number of database connections in use.  Statistics: The most useful statistics are Maximum and Sum.  Unit: The published unit is Count.     DiskQueueDepth  - The number of outstanding IOs (read/write requests) that are waiting to access the disk.  Statistics: The most useful statistic is Sum.  Unit: The published unit is Count.     FreeStorageSpace  - The amount of available storage space.  Statistics: The most useful statistic is Sum.  Unit: The published unit is Bytes.     NetworkReceiveThroughput  - The incoming (Receive) network traffic on the database, including both customer database traffic and AWS traffic used for monitoring and replication.  Statistics: The most useful statistic is Average.  Unit: The published unit is Bytes/Second.     NetworkTransmitThroughput  - The outgoing (Transmit) network traffic on the database, including both customer database traffic and AWS traffic used for monitoring and replication.  Statistics: The most useful statistic is Average.  Unit: The published unit is Bytes/Second.  .
        period(int): The granularity, in seconds, of the returned data points. All relational database metric data is available in 1-minute (60 seconds) granularity.
        start_time(str): The start of the time interval from which to get metric data. Constraints:   Specified in Coordinated Universal Time (UTC).   Specified in the Unix time format. For example, if you wish to use a start time of October 1, 2018, at 8 PM UTC, then you input 1538424000 as the start time.  .
        end_time(str): The end of the time interval from which to get metric data. Constraints:   Specified in Coordinated Universal Time (UTC).   Specified in the Unix time format. For example, if you wish to use an end time of October 1, 2018, at 8 PM UTC, then you input 1538424000 as the end time.  .
        unit(str): The unit for the metric data request. Valid units depend on the metric data being requested. For the valid units with each available metric, see the metricName parameter.
        statistics(List): The statistic for the metric. The following statistics are available:    Minimum - The lowest value observed during the specified period. Use this value to determine low volumes of activity for your application.    Maximum - The highest value observed during the specified period. Use this value to determine high volumes of activity for your application.    Sum - All values submitted for the matching metric added together. You can use this statistic to determine the total volume of a metric.    Average - The value of Sum / SampleCount during the specified period. By comparing this statistic with the Minimum and Maximum values, you can determine the full scope of a metric and how close the average use is to the Minimum and Maximum values. This comparison helps you to know when to increase or decrease your resources.    SampleCount - The count, or number, of data points used for the statistical calculation.  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.relational_database.metric_data.get(
                ctx,
                relational_database_name=value,
                metric_name=value,
                period=value,
                start_time=value,
                end_time=value,
                unit=value,
                statistics=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.relational_database.metric_data.get relational_database_name=value, metric_name=value, period=value, start_time=value, end_time=value, unit=value, statistics=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_relational_database_metric_data",
        op_kwargs={
            "relationalDatabaseName": relational_database_name,
            "metricName": metric_name,
            "period": period,
            "startTime": start_time,
            "endTime": end_time,
            "unit": unit,
            "statistics": statistics,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    cluster_arn: str,
    routing_control_name: str,
    client_token: str = None,
    control_panel_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new routing control. A routing control has one of two states: ON and OFF. You can map the routing control state to the state of an Amazon Route 53 health check, which can be used to control traffic routing. To get or update the routing control state, see the Recovery Cluster (data plane) API actions for Amazon Route 53 Application Recovery Controller.

    Args:
        client_token(str, optional): Unique client idempotency token. Defaults to None.
        cluster_arn(str): The Amazon Resource Name (ARN) of the cluster that includes the routing control.
        control_panel_arn(str, optional): The Amazon Resource Name (ARN) of the control panel that includes the routing control. Defaults to None.
        routing_control_name(str): The name of the routing control.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53_recovery_control_config.routing_control.create(
                ctx, cluster_arn=value, routing_control_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53_recovery_control_config.routing_control.create cluster_arn=value, routing_control_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53-recovery-control-config",
        operation="create_routing_control",
        op_kwargs={
            "ClientToken": client_token,
            "ClusterArn": cluster_arn,
            "ControlPanelArn": control_panel_arn,
            "RoutingControlName": routing_control_name,
        },
    )


async def delete(hub, ctx, routing_control_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a routing control.

    Args:
        routing_control_arn(str): The Amazon Resource Name (ARN) of the routing control that you're deleting.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53_recovery_control_config.routing_control.delete(
                ctx, routing_control_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53_recovery_control_config.routing_control.delete routing_control_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53-recovery-control-config",
        operation="delete_routing_control",
        op_kwargs={"RoutingControlArn": routing_control_arn},
    )


async def describe(hub, ctx, routing_control_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Displays details about a routing control. A routing control has one of two states: ON and OFF. You can map the routing control state to the state of an Amazon Route 53 health check, which can be used to control routing. To get or update the routing control state, see the Recovery Cluster (data plane) API actions for Amazon Route 53 Application Recovery Controller.

    Args:
        routing_control_arn(str): The Amazon Resource Name (ARN) of the routing control that you're getting details for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53_recovery_control_config.routing_control.describe(
                ctx, routing_control_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53_recovery_control_config.routing_control.describe routing_control_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53-recovery-control-config",
        operation="describe_routing_control",
        op_kwargs={"RoutingControlArn": routing_control_arn},
    )


async def list_all(
    hub, ctx, control_panel_arn: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns an array of routing controls for a control panel. A routing control is an Amazon Route 53 Application Recovery Controller construct that has one of two states: ON and OFF. You can map the routing control state to the state of an Amazon Route 53 health check, which can be used to control routing.

    Args:
        control_panel_arn(str): The Amazon Resource Name (ARN) of the control panel that you're getting routing control details for.
        max_results(int, optional): The number of objects that you want to return with this call. Defaults to None.
        next_token(str, optional): The token that identifies which batch of results you want to see. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53_recovery_control_config.routing_control.list_all(
                ctx, control_panel_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53_recovery_control_config.routing_control.list_all control_panel_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53-recovery-control-config",
        operation="list_routing_controls",
        op_kwargs={
            "ControlPanelArn": control_panel_arn,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(hub, ctx, routing_control_arn: str, routing_control_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Updates a routing control. You can only update the name of the routing control. To get or update the routing control state, see the Recovery Cluster (data plane) API actions for Amazon Route 53 Application Recovery Controller.

    Args:
        routing_control_arn(str): The Amazon Resource Name (ARN) of the routing control.
        routing_control_name(str): The name of the routing control.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53_recovery_control_config.routing_control.update(
                ctx, routing_control_arn=value, routing_control_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53_recovery_control_config.routing_control.update routing_control_arn=value, routing_control_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53-recovery-control-config",
        operation="update_routing_control",
        op_kwargs={
            "RoutingControlArn": routing_control_arn,
            "RoutingControlName": routing_control_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, alias_name: str, target_key_id: str) -> None:
    r"""
    **Autogenerated function**

    Creates a friendly name for a customer master key (CMK).   Adding, deleting, or updating an alias can allow or deny permission to the CMK. For details, see Using ABAC in AWS KMS in the AWS Key Management Service Developer Guide.  You can use an alias to identify a CMK in the AWS KMS console, in the DescribeKey operation and in cryptographic operations, such as Encrypt and GenerateDataKey. You can also change the CMK that's associated with the alias (UpdateAlias) or delete the alias (DeleteAlias) at any time. These operations don't affect the underlying CMK.  You can associate the alias with any customer managed CMK in the same AWS Region. Each alias is associated with only one CMK at a time, but a CMK can have multiple aliases. A valid CMK is required. You can't create an alias without a CMK. The alias must be unique in the account and Region, but you can have aliases with the same name in different Regions. For detailed information about aliases, see Using aliases in the AWS Key Management Service Developer Guide. This operation does not return a response. To get the alias that you created, use the ListAliases operation. The CMK that you use for this operation must be in a compatible key state. For details, see Key state: Effect on your CMK in the AWS Key Management Service Developer Guide.  Cross-account use: No. You cannot perform this operation on an alias in a different AWS account.  Required permissions     kms:CreateAlias on the alias (IAM policy).    kms:CreateAlias on the CMK (key policy).   For details, see Controlling access to aliases in the AWS Key Management Service Developer Guide.  Related operations:     DeleteAlias     ListAliases     UpdateAlias

    Args:
        alias_name(str): Specifies the alias name. This value must begin with alias/ followed by a name, such as alias/ExampleAlias.  The AliasName value must be string of 1-256 characters. It can contain only alphanumeric characters, forward slashes (/), underscores (_), and dashes (-). The alias name cannot begin with alias/aws/. The alias/aws/ prefix is reserved for AWS managed CMKs.
        target_key_id(str): Associates the alias with the specified customer managed CMK. The CMK must be in the same AWS Region.  A valid CMK ID is required. If you supply a null or empty string value, this operation returns an error. For help finding the key ID and ARN, see Finding the Key ID and ARN in the AWS Key Management Service Developer Guide. Specify the key ID or key ARN of the CMK. For example:   Key ID: 1234abcd-12ab-34cd-56ef-1234567890ab    Key ARN: arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab    To get the key ID and key ARN for a CMK, use ListKeys or DescribeKey.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.alias.create(ctx, alias_name=value, target_key_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.alias.create alias_name=value, target_key_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="create_alias",
        op_kwargs={"AliasName": alias_name, "TargetKeyId": target_key_id},
    )


async def delete(hub, ctx, alias_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified alias.   Adding, deleting, or updating an alias can allow or deny permission to the CMK. For details, see Using ABAC in AWS KMS in the AWS Key Management Service Developer Guide.  Because an alias is not a property of a CMK, you can delete and change the aliases of a CMK without affecting the CMK. Also, aliases do not appear in the response from the DescribeKey operation. To get the aliases of all CMKs, use the ListAliases operation.  Each CMK can have multiple aliases. To change the alias of a CMK, use DeleteAlias to delete the current alias and CreateAlias to create a new alias. To associate an existing alias with a different customer master key (CMK), call UpdateAlias.  Cross-account use: No. You cannot perform this operation on an alias in a different AWS account.  Required permissions     kms:DeleteAlias on the alias (IAM policy).    kms:DeleteAlias on the CMK (key policy).   For details, see Controlling access to aliases in the AWS Key Management Service Developer Guide.  Related operations:     CreateAlias     ListAliases     UpdateAlias

    Args:
        alias_name(str): The alias to be deleted. The alias name must begin with alias/ followed by the alias name, such as alias/ExampleAlias.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.alias.delete(ctx, alias_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.alias.delete alias_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="delete_alias",
        op_kwargs={"AliasName": alias_name},
    )


async def list_all(
    hub, ctx, key_id: str = None, limit: int = None, marker: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of aliases in the caller's AWS account and region. For more information about aliases, see CreateAlias. By default, the ListAliases operation returns all aliases in the account and region. To get only the aliases associated with a particular customer master key (CMK), use the KeyId parameter. The ListAliases response can include aliases that you created and associated with your customer managed CMKs, and aliases that AWS created and associated with AWS managed CMKs in your account. You can recognize AWS aliases because their names have the format aws/<service-name>, such as aws/dynamodb. The response might also include aliases that have no TargetKeyId field. These are predefined aliases that AWS has created but has not yet associated with a CMK. Aliases that AWS creates in your account, including predefined aliases, do not count against your AWS KMS aliases quota.  Cross-account use: No. ListAliases does not return aliases in other AWS accounts.  Required permissions: kms:ListAliases (IAM policy) For details, see Controlling access to aliases in the AWS Key Management Service Developer Guide.  Related operations:     CreateAlias     DeleteAlias     UpdateAlias

    Args:
        key_id(str, optional): Lists only aliases that are associated with the specified CMK. Enter a CMK in your AWS account.  This parameter is optional. If you omit it, ListAliases returns all aliases in the account and Region. Specify the key ID or key ARN of the CMK. For example:   Key ID: 1234abcd-12ab-34cd-56ef-1234567890ab    Key ARN: arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab    To get the key ID and key ARN for a CMK, use ListKeys or DescribeKey. Defaults to None.
        limit(int, optional): Use this parameter to specify the maximum number of items to return. When this value is present, AWS KMS does not return more than the specified number of items, but it might return fewer. This value is optional. If you include a value, it must be between 1 and 100, inclusive. If you do not include a value, it defaults to 50. Defaults to None.
        marker(str, optional): Use this parameter in a subsequent request after you receive a response with truncated results. Set it to the value of NextMarker from the truncated response you just received. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.alias.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.alias.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="list_aliases",
        op_kwargs={"KeyId": key_id, "Limit": limit, "Marker": marker},
    )


async def update(hub, ctx, alias_name: str, target_key_id: str) -> None:
    r"""
    **Autogenerated function**

    Associates an existing AWS KMS alias with a different customer master key (CMK). Each alias is associated with only one CMK at a time, although a CMK can have multiple aliases. The alias and the CMK must be in the same AWS account and Region.  Adding, deleting, or updating an alias can allow or deny permission to the CMK. For details, see Using ABAC in AWS KMS in the AWS Key Management Service Developer Guide.  The current and new CMK must be the same type (both symmetric or both asymmetric), and they must have the same key usage (ENCRYPT_DECRYPT or SIGN_VERIFY). This restriction prevents errors in code that uses aliases. If you must assign an alias to a different type of CMK, use DeleteAlias to delete the old alias and CreateAlias to create a new alias. You cannot use UpdateAlias to change an alias name. To change an alias name, use DeleteAlias to delete the old alias and CreateAlias to create a new alias. Because an alias is not a property of a CMK, you can create, update, and delete the aliases of a CMK without affecting the CMK. Also, aliases do not appear in the response from the DescribeKey operation. To get the aliases of all CMKs in the account, use the ListAliases operation.  The CMK that you use for this operation must be in a compatible key state. For details, see Key state: Effect on your CMK in the AWS Key Management Service Developer Guide.  Cross-account use: No. You cannot perform this operation on a CMK in a different AWS account.   Required permissions     kms:UpdateAlias on the alias (IAM policy).    kms:UpdateAlias on the current CMK (key policy).    kms:UpdateAlias on the new CMK (key policy).   For details, see Controlling access to aliases in the AWS Key Management Service Developer Guide.  Related operations:     CreateAlias     DeleteAlias     ListAliases

    Args:
        alias_name(str): Identifies the alias that is changing its CMK. This value must begin with alias/ followed by the alias name, such as alias/ExampleAlias. You cannot use UpdateAlias to change the alias name.
        target_key_id(str): Identifies the customer managed CMK to associate with the alias. You don't have permission to associate an alias with an AWS managed CMK. The CMK must be in the same AWS account and Region as the alias. Also, the new target CMK must be the same type as the current target CMK (both symmetric or both asymmetric) and they must have the same key usage.  Specify the key ID or key ARN of the CMK. For example:   Key ID: 1234abcd-12ab-34cd-56ef-1234567890ab    Key ARN: arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab    To get the key ID and key ARN for a CMK, use ListKeys or DescribeKey. To verify that the alias is mapped to the correct CMK, use ListAliases.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.alias.update(ctx, alias_name=value, target_key_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.alias.update alias_name=value, target_key_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="update_alias",
        op_kwargs={"AliasName": alias_name, "TargetKeyId": target_key_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    name: str,
    code: Dict,
    artifact_s3_location: str,
    execution_role_arn: str,
    schedule: Dict,
    runtime_version: str,
    run_config: Dict = None,
    success_retention_period_in_days: int = None,
    failure_retention_period_in_days: int = None,
    vpc_config: Dict = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a canary. Canaries are scripts that monitor your endpoints and APIs from the outside-in. Canaries help you check the availability and latency of your web services and troubleshoot anomalies by investigating load time data, screenshots of the UI, logs, and metrics. You can set up a canary to run continuously or just once.  Do not use CreateCanary to modify an existing canary. Use UpdateCanary instead. To create canaries, you must have the CloudWatchSyntheticsFullAccess policy. If you are creating a new IAM role for the canary, you also need the the iam:CreateRole, iam:CreatePolicy and iam:AttachRolePolicy permissions. For more information, see Necessary Roles and Permissions. Do not include secrets or proprietary information in your canary names. The canary name makes up part of the Amazon Resource Name (ARN) for the canary, and the ARN is included in outbound calls over the internet. For more information, see Security Considerations for Synthetics Canaries.

    Args:
        name(str): The name for this canary. Be sure to give it a descriptive name that distinguishes it from other canaries in your account. Do not include secrets or proprietary information in your canary names. The canary name makes up part of the canary ARN, and the ARN is included in outbound calls over the internet. For more information, see Security Considerations for Synthetics Canaries.
        code(Dict): A structure that includes the entry point from which the canary should start running your script. If the script is stored in an S3 bucket, the bucket name, key, and version are also included. .
        artifact_s3_location(str): The location in Amazon S3 where Synthetics stores artifacts from the test runs of this canary. Artifacts include the log file, screenshots, and HAR files. The name of the S3 bucket can't include a period (.).
        execution_role_arn(str): The ARN of the IAM role to be used to run the canary. This role must already exist, and must include lambda.amazonaws.com as a principal in the trust policy. The role must also have the following permissions:    s3:PutObject     s3:GetBucketLocation     s3:ListAllMyBuckets     cloudwatch:PutMetricData     logs:CreateLogGroup     logs:CreateLogStream     logs:PutLogEvents   .
        schedule(Dict): A structure that contains information about how often the canary is to run and when these test runs are to stop.
        run_config(Dict, optional): A structure that contains the configuration for individual canary runs, such as timeout value. Defaults to None.
        success_retention_period_in_days(int, optional): The number of days to retain data about successful runs of this canary. If you omit this field, the default of 31 days is used. The valid range is 1 to 455 days. Defaults to None.
        failure_retention_period_in_days(int, optional): The number of days to retain data about failed runs of this canary. If you omit this field, the default of 31 days is used. The valid range is 1 to 455 days. Defaults to None.
        runtime_version(str): Specifies the runtime version to use for the canary. For a list of valid runtime versions and more information about runtime versions, see  Canary Runtime Versions.
        vpc_config(Dict, optional): If this canary is to test an endpoint in a VPC, this structure contains information about the subnet and security groups of the VPC endpoint. For more information, see  Running a Canary in a VPC. Defaults to None.
        tags(Dict, optional): A list of key-value pairs to associate with the canary. You can associate as many as 50 tags with a canary. Tags can help you organize and categorize your resources. You can also use them to scope user permissions, by granting a user permission to access or change only the resources that have certain tag values. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.synthetic.canary.init.create(
                ctx,
                name=value,
                code=value,
                artifact_s3_location=value,
                execution_role_arn=value,
                schedule=value,
                runtime_version=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.synthetic.canary.init.create name=value, code=value, artifact_s3_location=value, execution_role_arn=value, schedule=value, runtime_version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="synthetics",
        operation="create_canary",
        op_kwargs={
            "Name": name,
            "Code": code,
            "ArtifactS3Location": artifact_s3_location,
            "ExecutionRoleArn": execution_role_arn,
            "Schedule": schedule,
            "RunConfig": run_config,
            "SuccessRetentionPeriodInDays": success_retention_period_in_days,
            "FailureRetentionPeriodInDays": failure_retention_period_in_days,
            "RuntimeVersion": runtime_version,
            "VpcConfig": vpc_config,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Permanently deletes the specified canary. When you delete a canary, resources used and created by the canary are not automatically deleted. After you delete a canary that you do not intend to use again, you should also delete the following:   The Lambda functions and layers used by this canary. These have the prefix cwsyn-MyCanaryName .   The CloudWatch alarms created for this canary. These alarms have a name of Synthetics-SharpDrop-Alarm-MyCanaryName .   Amazon S3 objects and buckets, such as the canary's artifact location.   IAM roles created for the canary. If they were created in the console, these roles have the name  role/service-role/CloudWatchSyntheticsRole-MyCanaryName .   CloudWatch Logs log groups created for the canary. These logs groups have the name /aws/lambda/cwsyn-MyCanaryName .    Before you delete a canary, you might want to use GetCanary to display the information about this canary. Make note of the information returned by this operation so that you can delete these resources after you delete the canary.

    Args:
        name(str): The name of the canary that you want to delete. To find the names of your canaries, use DescribeCanaries.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.synthetic.canary.init.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.synthetic.canary.init.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="synthetics",
        operation="delete_canary",
        op_kwargs={"Name": name},
    )


async def describe_all(
    hub, ctx, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    This operation returns a list of the canaries in your account, along with full details about each canary. This operation does not have resource-level authorization, so if a user is able to use DescribeCanaries, the user can see all of the canaries in the account. A deny policy can only be used to restrict access to all canaries. It cannot be used on specific resources.

    Args:
        next_token(str, optional): A token that indicates that there is more data available. You can use this token in a subsequent operation to retrieve the next set of results. Defaults to None.
        max_results(int, optional): Specify this parameter to limit how many canaries are returned each time you use the DescribeCanaries operation. If you omit this parameter, the default of 100 is used. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.synthetic.canary.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.synthetic.canary.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="synthetics",
        operation="describe_canaries",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )


async def get(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves complete information about one canary. You must specify the name of the canary that you want. To get a list of canaries and their names, use DescribeCanaries.

    Args:
        name(str): The name of the canary that you want details for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.synthetic.canary.init.get(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.synthetic.canary.init.get name=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="synthetics", operation="get_canary", op_kwargs={"Name": name}
    )


async def start(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Use this operation to run a canary that has already been created. The frequency of the canary runs is determined by the value of the canary's Schedule. To see a canary's schedule, use GetCanary.

    Args:
        name(str): The name of the canary that you want to run. To find canary names, use DescribeCanaries.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.synthetic.canary.init.start(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.synthetic.canary.init.start name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="synthetics",
        operation="start_canary",
        op_kwargs={"Name": name},
    )


async def stop(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Stops the canary to prevent all future runs. If the canary is currently running, Synthetics stops waiting for the current run of the specified canary to complete. The run that is in progress completes on its own, publishes metrics, and uploads artifacts, but it is not recorded in Synthetics as a completed run. You can use StartCanary to start it running again with the canary’s current schedule at any point in the future.

    Args:
        name(str): The name of the canary that you want to stop. To find the names of your canaries, use DescribeCanaries.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.synthetic.canary.init.stop(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.synthetic.canary.init.stop name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="synthetics",
        operation="stop_canary",
        op_kwargs={"Name": name},
    )


async def update(
    hub,
    ctx,
    name: str,
    code: Dict = None,
    execution_role_arn: str = None,
    runtime_version: str = None,
    schedule: Dict = None,
    run_config: Dict = None,
    success_retention_period_in_days: int = None,
    failure_retention_period_in_days: int = None,
    vpc_config: Dict = None,
    visual_reference: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Use this operation to change the settings of a canary that has already been created. You can't use this operation to update the tags of an existing canary. To change the tags of an existing canary, use TagResource.

    Args:
        name(str): The name of the canary that you want to update. To find the names of your canaries, use DescribeCanaries. You cannot change the name of a canary that has already been created.
        code(Dict, optional): A structure that includes the entry point from which the canary should start running your script. If the script is stored in an S3 bucket, the bucket name, key, and version are also included. . Defaults to None.
        execution_role_arn(str, optional): The ARN of the IAM role to be used to run the canary. This role must already exist, and must include lambda.amazonaws.com as a principal in the trust policy. The role must also have the following permissions:    s3:PutObject     s3:GetBucketLocation     s3:ListAllMyBuckets     cloudwatch:PutMetricData     logs:CreateLogGroup     logs:CreateLogStream     logs:CreateLogStream   . Defaults to None.
        runtime_version(str, optional): Specifies the runtime version to use for the canary. For a list of valid runtime versions and for more information about runtime versions, see  Canary Runtime Versions. Defaults to None.
        schedule(Dict, optional): A structure that contains information about how often the canary is to run, and when these runs are to stop. Defaults to None.
        run_config(Dict, optional): A structure that contains the timeout value that is used for each individual run of the canary. Defaults to None.
        success_retention_period_in_days(int, optional): The number of days to retain data about successful runs of this canary. Defaults to None.
        failure_retention_period_in_days(int, optional): The number of days to retain data about failed runs of this canary. Defaults to None.
        vpc_config(Dict, optional): If this canary is to test an endpoint in a VPC, this structure contains information about the subnet and security groups of the VPC endpoint. For more information, see  Running a Canary in a VPC. Defaults to None.
        visual_reference(Dict, optional): . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.synthetic.canary.init.update(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.synthetic.canary.init.update name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="synthetics",
        operation="update_canary",
        op_kwargs={
            "Name": name,
            "Code": code,
            "ExecutionRoleArn": execution_role_arn,
            "RuntimeVersion": runtime_version,
            "Schedule": schedule,
            "RunConfig": run_config,
            "SuccessRetentionPeriodInDays": success_retention_period_in_days,
            "FailureRetentionPeriodInDays": failure_retention_period_in_days,
            "VpcConfig": vpc_config,
            "VisualReference": visual_reference,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def disable(
    hub, ctx, pipeline_name: str, stage_name: str, transition_type: str, reason: str
) -> None:
    r"""
    **Autogenerated function**

    Prevents artifacts in a pipeline from transitioning to the next stage in the pipeline.

    Args:
        pipeline_name(str): The name of the pipeline in which you want to disable the flow of artifacts from one stage to another.
        stage_name(str): The name of the stage where you want to disable the inbound or outbound transition of artifacts.
        transition_type(str): Specifies whether artifacts are prevented from transitioning into the stage and being processed by the actions in that stage (inbound), or prevented from transitioning from the stage after they have been processed by the actions in that stage (outbound).
        reason(str): The reason given to the user that a stage is disabled, such as waiting for manual approval or manual tests. This message is displayed in the pipeline console UI.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codepipeline.stage.transition.disable(
                ctx, pipeline_name=value, stage_name=value, transition_type=value, reason=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codepipeline.stage.transition.disable pipeline_name=value, stage_name=value, transition_type=value, reason=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codepipeline",
        operation="disable_stage_transition",
        op_kwargs={
            "pipelineName": pipeline_name,
            "stageName": stage_name,
            "transitionType": transition_type,
            "reason": reason,
        },
    )


async def enable(
    hub, ctx, pipeline_name: str, stage_name: str, transition_type: str
) -> None:
    r"""
    **Autogenerated function**

    Enables artifacts in a pipeline to transition to a stage in a pipeline.

    Args:
        pipeline_name(str): The name of the pipeline in which you want to enable the flow of artifacts from one stage to another.
        stage_name(str): The name of the stage where you want to enable the transition of artifacts, either into the stage (inbound) or from that stage to the next stage (outbound).
        transition_type(str): Specifies whether artifacts are allowed to enter the stage and be processed by the actions in that stage (inbound) or whether already processed artifacts are allowed to transition to the next stage (outbound).
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codepipeline.stage.transition.enable(
                ctx, pipeline_name=value, stage_name=value, transition_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codepipeline.stage.transition.enable pipeline_name=value, stage_name=value, transition_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codepipeline",
        operation="enable_stage_transition",
        op_kwargs={
            "pipelineName": pipeline_name,
            "stageName": stage_name,
            "transitionType": transition_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    compute_environment_name: str,
    type_: str,
    state: str = None,
    compute_resources: Dict = None,
    service_role: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Batch compute environment. You can create MANAGED or UNMANAGED compute environments. MANAGED compute environments can use Amazon EC2 or Fargate resources. UNMANAGED compute environments can only use EC2 resources. In a managed compute environment, Batch manages the capacity and instance types of the compute resources within the environment. This is based on the compute resource specification that you define or the launch template that you specify when you create the compute environment. Either, you can choose to use EC2 On-Demand Instances and EC2 Spot Instances. Or, you can use Fargate and Fargate Spot capacity in your managed compute environment. You can optionally set a maximum price so that Spot Instances only launch when the Spot Instance price is less than a specified percentage of the On-Demand price.  Multi-node parallel jobs aren't supported on Spot Instances.  In an unmanaged compute environment, you can manage your own EC2 compute resources and have a lot of flexibility with how you configure your compute resources. For example, you can use custom AMIs. However, you must verify that each of your AMIs meet the Amazon ECS container instance AMI specification. For more information, see container instance AMIs in the Amazon Elastic Container Service Developer Guide. After you created your unmanaged compute environment, you can use the DescribeComputeEnvironments operation to find the Amazon ECS cluster that's associated with it. Then, launch your container instances into that Amazon ECS cluster. For more information, see Launching an Amazon ECS container instance in the Amazon Elastic Container Service Developer Guide.  Batch doesn't upgrade the AMIs in a compute environment after the environment is created. For example, it doesn't update the AMIs when a newer version of the Amazon ECS optimized AMI is available. Therefore, you're responsible for managing the guest operating system (including its updates and security patches) and any additional application software or utilities that you install on the compute resources. To use a new AMI for your Batch jobs, complete these steps:   Create a new compute environment with the new AMI.   Add the compute environment to an existing job queue.   Remove the earlier compute environment from your job queue.   Delete the earlier compute environment.

    Args:
        compute_environment_name(str): The name for your compute environment. Up to 128 letters (uppercase and lowercase), numbers, hyphens, and underscores are allowed.
        type_(str): The type of the compute environment: MANAGED or UNMANAGED. For more information, see Compute Environments in the Batch User Guide.
        state(str, optional): The state of the compute environment. If the state is ENABLED, then the compute environment accepts jobs from a queue and can scale out automatically based on queues. If the state is ENABLED, then the Batch scheduler can attempt to place jobs from an associated job queue on the compute resources within the environment. If the compute environment is managed, then it can scale its instances out or in automatically, based on the job queue demand. If the state is DISABLED, then the Batch scheduler doesn't attempt to place jobs within the environment. Jobs in a STARTING or RUNNING state continue to progress normally. Managed compute environments in the DISABLED state don't scale out. However, they scale in to minvCpus value after instances become idle. Defaults to None.
        compute_resources(Dict, optional): Details about the compute resources managed by the compute environment. This parameter is required for managed compute environments. For more information, see Compute Environments in the Batch User Guide. Defaults to None.
        service_role(str, optional): The full Amazon Resource Name (ARN) of the IAM role that allows Batch to make calls to other Amazon Web Services services on your behalf. For more information, see Batch service IAM role in the Batch User Guide.  If your account already created the Batch service-linked role, that role is used by default for your compute environment unless you specify a different role here. If the Batch service-linked role doesn't exist in your account, and no role is specified here, the service attempts to create the Batch service-linked role in your account.  If your specified role has a path other than /, then you must specify either the full role ARN (recommended) or prefix the role name with the path. For example, if a role with the name bar has a path of /foo/ then you would specify /foo/bar as the role name. For more information, see Friendly names and paths in the IAM User Guide.  Depending on how you created your Batch service role, its ARN might contain the service-role path prefix. When you only specify the name of the service role, Batch assumes that your ARN doesn't use the service-role path prefix. Because of this, we recommend that you specify the full ARN of your service role when you create compute environments. . Defaults to None.
        tags(Dict, optional): The tags that you apply to the compute environment to help you categorize and organize your resources. Each tag consists of a key and an optional value. For more information, see Tagging Amazon Web Services Resources in Amazon Web Services General Reference. These tags can be updated or removed using the TagResource and UntagResource API operations. These tags don't propagate to the underlying compute resources. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.batch.compute_environment.create(
                ctx, compute_environment_name=value, type_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.batch.compute_environment.create compute_environment_name=value, type_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="batch",
        operation="create_compute_environment",
        op_kwargs={
            "computeEnvironmentName": compute_environment_name,
            "type": type_,
            "state": state,
            "computeResources": compute_resources,
            "serviceRole": service_role,
            "tags": tags,
        },
    )


async def delete(hub, ctx, compute_environment: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an Batch compute environment. Before you can delete a compute environment, you must set its state to DISABLED with the UpdateComputeEnvironment API operation and disassociate it from any job queues with the UpdateJobQueue API operation. Compute environments that use Fargate resources must terminate all active jobs on that compute environment before deleting the compute environment. If this isn't done, the compute environment enters an invalid state.

    Args:
        compute_environment(str): The name or Amazon Resource Name (ARN) of the compute environment to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.batch.compute_environment.delete(ctx, compute_environment=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.batch.compute_environment.delete compute_environment=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="batch",
        operation="delete_compute_environment",
        op_kwargs={"computeEnvironment": compute_environment},
    )


async def describe_all(
    hub,
    ctx,
    compute_environments: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more of your compute environments. If you're using an unmanaged compute environment, you can use the DescribeComputeEnvironment operation to determine the ecsClusterArn that you should launch your Amazon ECS container instances into.

    Args:
        compute_environments(List, optional): A list of up to 100 compute environment names or full Amazon Resource Name (ARN) entries. Defaults to None.
        max_results(int, optional): The maximum number of cluster results returned by DescribeComputeEnvironments in paginated output. When this parameter is used, DescribeComputeEnvironments only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another DescribeComputeEnvironments request with the returned nextToken value. This value can be between 1 and 100. If this parameter isn't used, then DescribeComputeEnvironments returns up to 100 results and a nextToken value if applicable. Defaults to None.
        next_token(str, optional): The nextToken value returned from a previous paginated DescribeComputeEnvironments request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. This value is null when there are no more results to return.  This token should be treated as an opaque identifier that's only used to retrieve the next items in a list and not for other programmatic purposes. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.batch.compute_environment.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.batch.compute_environment.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="batch",
        operation="describe_compute_environments",
        op_kwargs={
            "computeEnvironments": compute_environments,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    compute_environment: str,
    state: str = None,
    compute_resources: Dict = None,
    service_role: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an Batch compute environment.

    Args:
        compute_environment(str): The name or full Amazon Resource Name (ARN) of the compute environment to update.
        state(str, optional): The state of the compute environment. Compute environments in the ENABLED state can accept jobs from a queue and scale in or out automatically based on the workload demand of its associated queues. If the state is ENABLED, then the Batch scheduler can attempt to place jobs from an associated job queue on the compute resources within the environment. If the compute environment is managed, then it can scale its instances out or in automatically, based on the job queue demand. If the state is DISABLED, then the Batch scheduler doesn't attempt to place jobs within the environment. Jobs in a STARTING or RUNNING state continue to progress normally. Managed compute environments in the DISABLED state don't scale out. However, they scale in to minvCpus value after instances become idle. Defaults to None.
        compute_resources(Dict, optional): Details of the compute resources managed by the compute environment. Required for a managed compute environment. For more information, see Compute Environments in the Batch User Guide. Defaults to None.
        service_role(str, optional): The full Amazon Resource Name (ARN) of the IAM role that allows Batch to make calls to other Amazon Web Services services on your behalf. For more information, see Batch service IAM role in the Batch User Guide.  If the compute environment has a service-linked role, it can't be changed to use a regular IAM role. Likewise, if the compute environment has a regular IAM role, it can't be changed to use a service-linked role.  If your specified role has a path other than /, then you must either specify the full role ARN (this is recommended) or prefix the role name with the path.  Depending on how you created your Batch service role, its ARN might contain the service-role path prefix. When you only specify the name of the service role, Batch assumes that your ARN doesn't use the service-role path prefix. Because of this, we recommend that you specify the full ARN of your service role when you create compute environments. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.batch.compute_environment.update(ctx, compute_environment=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.batch.compute_environment.update compute_environment=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="batch",
        operation="update_compute_environment",
        op_kwargs={
            "computeEnvironment": compute_environment,
            "state": state,
            "computeResources": compute_resources,
            "serviceRole": service_role,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    policy_id: str,
    member_account_id: str = None,
    start_time: str = None,
    end_time: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    If you created a Shield Advanced policy, returns policy-level attack summary information in the event of a potential DDoS attack. Other policy types are currently unsupported.

    Args:
        policy_id(str): The ID of the policy for which you want to get the attack information.
        member_account_id(str, optional): The Amazon Web Services account that is in scope of the policy that you want to get the details for. Defaults to None.
        start_time(str, optional): The start of the time period to query for the attacks. This is a timestamp type. The request syntax listing indicates a number type because the default used by Firewall Manager is Unix time in seconds. However, any valid timestamp format is allowed. Defaults to None.
        end_time(str, optional): The end of the time period to query for the attacks. This is a timestamp type. The request syntax listing indicates a number type because the default used by Firewall Manager is Unix time in seconds. However, any valid timestamp format is allowed. Defaults to None.
        next_token(str, optional): If you specify a value for MaxResults and you have more objects than the number that you specify for MaxResults, Firewall Manager returns a NextToken value in the response, which you can use to retrieve another group of objects. For the second and subsequent GetProtectionStatus requests, specify the value of NextToken from the previous response to get information about another batch of objects. Defaults to None.
        max_results(int, optional): Specifies the number of objects that you want Firewall Manager to return for this request. If you have more objects than the number that you specify for MaxResults, the response includes a NextToken value that you can use to get another batch of objects. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fms.protection_status.get(ctx, policy_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fms.protection_status.get policy_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fms",
        operation="get_protection_status",
        op_kwargs={
            "PolicyId": policy_id,
            "MemberAccountId": member_account_id,
            "StartTime": start_time,
            "EndTime": end_time,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def view(
    hub,
    ctx,
    start: str = None,
    end: str = None,
    marker: str = None,
    max_items: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns all the domain-related billing records for the current AWS account for a specified period

    Args:
        start(str, optional): The beginning date and time for the time period for which you want a list of billing records. Specify the date and time in Unix time format and Coordinated Universal time (UTC). Defaults to None.
        end(str, optional): The end date and time for the time period for which you want a list of billing records. Specify the date and time in Unix time format and Coordinated Universal time (UTC). Defaults to None.
        marker(str, optional): For an initial request for a list of billing records, omit this element. If the number of billing records that are associated with the current AWS account during the specified period is greater than the value that you specified for MaxItems, you can use Marker to return additional billing records. Get the value of NextPageMarker from the previous response, and submit another request that includes the value of NextPageMarker in the Marker element.  Constraints: The marker must match the value of NextPageMarker that was returned in the previous response. Defaults to None.
        max_items(int, optional): The number of billing records to be returned. Default: 20. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53domain.billing.view(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53domain.billing.view
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53domains",
        operation="view_billing",
        op_kwargs={"Start": start, "End": end, "Marker": marker, "MaxItems": max_items},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def put(
    hub,
    ctx,
    repository_name: str,
    image_scanning_configuration: Dict,
    registry_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the image scanning configuration for the specified repository.

    Args:
        registry_id(str, optional): The AWS account ID associated with the registry that contains the repository in which to update the image scanning configuration setting. If you do not specify a registry, the default registry is assumed. Defaults to None.
        repository_name(str): The name of the repository in which to update the image scanning configuration setting.
        image_scanning_configuration(Dict): The image scanning configuration for the repository. This setting determines whether images are scanned for known vulnerabilities after being pushed to the repository.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr.image.scanning_configuration.put(
                ctx, repository_name=value, image_scanning_configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr.image.scanning_configuration.put repository_name=value, image_scanning_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr",
        operation="put_image_scanning_configuration",
        op_kwargs={
            "registryId": registry_id,
            "repositoryName": repository_name,
            "imageScanningConfiguration": image_scanning_configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx, key: str, pagination_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns all tag values for the specified key that are used in the specified AWS Region for the calling AWS account. This operation supports pagination, where the response can be sent in multiple pages. You should check the PaginationToken response parameter to determine if there are additional results available to return. Repeat the query, passing the PaginationToken response parameter value as an input to the next request until you recieve a null value. A null value for PaginationToken indicates that there are no more results waiting to be returned.

    Args:
        pagination_token(str, optional): Specifies a PaginationToken response value from a previous request to indicate that you want the next page of results. Leave this parameter empty in your initial request. Defaults to None.
        key(str): Specifies the tag key for which you want to list all existing values that are currently used in the specified AWS Region for the calling AWS account.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.resourcegroupstaggingapi.tag.value.get_all(ctx, key=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.resourcegroupstaggingapi.tag.value.get_all key=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="resourcegroupstaggingapi",
        operation="get_tag_values",
        op_kwargs={"PaginationToken": pagination_token, "Key": key},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def test(
    hub,
    ctx,
    rest_api_id: str,
    authorizer_id: str,
    headers: Dict = None,
    multi_value_headers: Dict = None,
    path_with_query_string: str = None,
    body: str = None,
    stage_variables: Dict = None,
    additional_context: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Simulate the execution of an Authorizer in your RestApi with headers, parameters, and an incoming request body.  Use Lambda Function as Authorizer Use Cognito User Pool as Authorizer

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        authorizer_id(str): [Required] Specifies a test invoke authorizer request's Authorizer ID.
        headers(Dict, optional): [Required] A key-value map of headers to simulate an incoming invocation request. This is where the incoming authorization token, or identity source, should be specified. Defaults to None.
        multi_value_headers(Dict, optional): [Optional] The headers as a map from string to list of values to simulate an incoming invocation request. This is where the incoming authorization token, or identity source, may be specified. Defaults to None.
        path_with_query_string(str, optional): [Optional] The URI path, including query string, of the simulated invocation request. Use this to specify path parameters and query string parameters. Defaults to None.
        body(str, optional): [Optional] The simulated request body of an incoming invocation request. Defaults to None.
        stage_variables(Dict, optional): A key-value map of stage variables to simulate an invocation on a deployed Stage. Defaults to None.
        additional_context(Dict, optional): [Optional] A key-value map of additional context variables. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.invoke.authorizer.test(
                ctx, rest_api_id=value, authorizer_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.invoke.authorizer.test rest_api_id=value, authorizer_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="test_invoke_authorizer",
        op_kwargs={
            "restApiId": rest_api_id,
            "authorizerId": authorizer_id,
            "headers": headers,
            "multiValueHeaders": multi_value_headers,
            "pathWithQueryString": path_with_query_string,
            "body": body,
            "stageVariables": stage_variables,
            "additionalContext": additional_context,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(hub, ctx, type_: List, participant_token: str) -> Dict:
    r"""
    **Autogenerated function**

    Creates the participant's connection. Note that ParticipantToken is used for invoking this API instead of ConnectionToken. The participant token is valid for the lifetime of the participant – until they are part of a contact. The response URL for WEBSOCKET Type has a connect expiry timeout of 100s. Clients must manually connect to the returned websocket URL and subscribe to the desired topic.  For chat, you need to publish the following on the established websocket connection:  {"topic":"aws/subscribe","content":{"topics":["aws/chat"]}}  Upon websocket URL expiry, as specified in the response ConnectionExpiry parameter, clients need to call this API again to obtain a new websocket URL and perform the same steps as before.  The Amazon Connect Participant Service APIs do not use Signature Version 4 authentication.

    Args:
        type_(List): Type of connection information required.
        participant_token(str): This is a header parameter. The Participant Token as obtained from StartChatContact API response.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connectparticipant.participant.connection.create(
                ctx, type_=value, participant_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connectparticipant.participant.connection.create type_=value, participant_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connectparticipant",
        operation="create_participant_connection",
        op_kwargs={"Type": type_, "ParticipantToken": participant_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, instance_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the state of a specific instance. Works on one instance at a time.

    Args:
        instance_name(str): The name of the instance to get state information about.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.instance.state.get(ctx, instance_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.instance.state.get instance_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_instance_state",
        op_kwargs={"instanceName": instance_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the current IoT SiteWise logging options.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotsitewise.logging_option.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotsitewise.logging_option.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotsitewise",
        operation="describe_logging_options",
        op_kwargs={},
    )


async def put_multiple(hub, ctx, logging_options: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Sets logging options for IoT SiteWise.

    Args:
        logging_options(Dict): The logging options to set.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotsitewise.logging_option.put_multiple(
                ctx, logging_options=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotsitewise.logging_option.put_multiple logging_options=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotsitewise",
        operation="put_logging_options",
        op_kwargs={"loggingOptions": logging_options},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def accept(
    hub, ctx, ticket_id: str, player_ids: List, acceptance_type: str
) -> Dict:
    r"""
    **Autogenerated function**

    Registers a player's acceptance or rejection of a proposed FlexMatch match. A matchmaking configuration may require player acceptance; if so, then matches built with that configuration cannot be completed unless all players accept the proposed match within a specified time limit.  When FlexMatch builds a match, all the matchmaking tickets involved in the proposed match are placed into status REQUIRES_ACCEPTANCE. This is a trigger for your game to get acceptance from all players in the ticket. Acceptances are only valid for tickets when they are in this status; all other acceptances result in an error. To register acceptance, specify the ticket ID, a response, and one or more players. Once all players have registered acceptance, the matchmaking tickets advance to status PLACING, where a new game session is created for the match.  If any player rejects the match, or if acceptances are not received before a specified timeout, the proposed match is dropped. The matchmaking tickets are then handled in one of two ways: For tickets where one or more players rejected the match, the ticket status is returned to SEARCHING to find a new match. For tickets where one or more players failed to respond, the ticket status is set to CANCELLED, and processing is terminated. A new matchmaking request for these players can be submitted as needed.   Learn more    Add FlexMatch to a game client    FlexMatch events (reference)  Related actions   StartMatchmaking | DescribeMatchmaking | StopMatchmaking | AcceptMatch | StartMatchBackfill | All APIs by task

    Args:
        ticket_id(str): A unique identifier for a matchmaking ticket. The ticket must be in status REQUIRES_ACCEPTANCE; otherwise this request will fail.
        player_ids(List): A unique identifier for a player delivering the response. This parameter can include one or multiple player IDs.
        acceptance_type(str): Player response to the proposed match.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.match.init.accept(
                ctx, ticket_id=value, player_ids=value, acceptance_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.match.init.accept ticket_id=value, player_ids=value, acceptance_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="accept_match",
        op_kwargs={
            "TicketId": ticket_id,
            "PlayerIds": player_ids,
            "AcceptanceType": acceptance_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub, ctx, resource: Dict, catalog_id: str = None, show_assigned_lf_tags: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the tags applied to a resource.

    Args:
        catalog_id(str, optional): The identifier for the Data Catalog. By default, the account ID. The Data Catalog is the persistent metadata store. It contains database definitions, table definitions, and other control information to manage your AWS Lake Formation environment. . Defaults to None.
        resource(Dict): The resource for which you want to return tags.
        show_assigned_lf_tags(bool, optional): Indicates whether to show the assigned tags. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lakeformation.resource.lf_tag.get_all(ctx, resource=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lakeformation.resource.lf_tag.get_all resource=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lakeformation",
        operation="get_resource_lf_tags",
        op_kwargs={
            "CatalogId": catalog_id,
            "Resource": resource,
            "ShowAssignedLFTags": show_assigned_lf_tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list that describes the configuration of Bring Your Own License (BYOL) for the specified account.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.account.init.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.account.init.describe
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="workspaces", operation="describe_account", op_kwargs={}
    )


async def modify(
    hub,
    ctx,
    dedicated_tenancy_support: str = None,
    dedicated_tenancy_management_cidr_range: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the configuration of Bring Your Own License (BYOL) for the specified account.

    Args:
        dedicated_tenancy_support(str, optional): The status of BYOL. Defaults to None.
        dedicated_tenancy_management_cidr_range(str, optional): The IP address range, specified as an IPv4 CIDR block, for the management network interface. Specify an IP address range that is compatible with your network and in CIDR notation (that is, specify the range as an IPv4 CIDR block). The CIDR block size must be /16 (for example, 203.0.113.25/16). It must also be specified as available by the ListAvailableManagementCidrRanges operation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.account.init.modify(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.account.init.modify
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="modify_account",
        op_kwargs={
            "DedicatedTenancySupport": dedicated_tenancy_support,
            "DedicatedTenancyManagementCidrRange": dedicated_tenancy_management_cidr_range,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    job_queue_name: str,
    priority: int,
    compute_environment_order: List,
    state: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Batch job queue. When you create a job queue, you associate one or more compute environments to the queue and assign an order of preference for the compute environments. You also set a priority to the job queue that determines the order that the Batch scheduler places jobs onto its associated compute environments. For example, if a compute environment is associated with more than one job queue, the job queue with a higher priority is given preference for scheduling jobs to that compute environment.

    Args:
        job_queue_name(str): The name of the job queue. Up to 128 letters (uppercase and lowercase), numbers, and underscores are allowed.
        state(str, optional): The state of the job queue. If the job queue state is ENABLED, it is able to accept jobs. If the job queue state is DISABLED, new jobs can't be added to the queue, but jobs already in the queue can finish. Defaults to None.
        priority(int): The priority of the job queue. Job queues with a higher priority (or a higher integer value for the priority parameter) are evaluated first when associated with the same compute environment. Priority is determined in descending order. For example, a job queue with a priority value of 10 is given scheduling preference over a job queue with a priority value of 1. All of the compute environments must be either EC2 (EC2 or SPOT) or Fargate (FARGATE or FARGATE_SPOT); EC2 and Fargate compute environments can't be mixed.
        compute_environment_order(List): The set of compute environments mapped to a job queue and their order relative to each other. The job scheduler uses this parameter to determine which compute environment should run a specific job. Compute environments must be in the VALID state before you can associate them with a job queue. You can associate up to three compute environments with a job queue. All of the compute environments must be either EC2 (EC2 or SPOT) or Fargate (FARGATE or FARGATE_SPOT); EC2 and Fargate compute environments can't be mixed.  All compute environments that are associated with a job queue must share the same architecture. Batch doesn't support mixing compute environment architecture types in a single job queue. .
        tags(Dict, optional): The tags that you apply to the job queue to help you categorize and organize your resources. Each tag consists of a key and an optional value. For more information, see Tagging your Batch resources in Batch User Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.batch.job.queue.create(
                ctx, job_queue_name=value, priority=value, compute_environment_order=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.batch.job.queue.create job_queue_name=value, priority=value, compute_environment_order=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="batch",
        operation="create_job_queue",
        op_kwargs={
            "jobQueueName": job_queue_name,
            "state": state,
            "priority": priority,
            "computeEnvironmentOrder": compute_environment_order,
            "tags": tags,
        },
    )


async def delete(hub, ctx, job_queue: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified job queue. You must first disable submissions for a queue with the UpdateJobQueue operation. All jobs in the queue are eventually terminated when you delete a job queue. The jobs are terminated at a rate of about 16 jobs each second. It's not necessary to disassociate compute environments from a queue before submitting a DeleteJobQueue request.

    Args:
        job_queue(str): The short name or full Amazon Resource Name (ARN) of the queue to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.batch.job.queue.delete(ctx, job_queue=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.batch.job.queue.delete job_queue=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="batch",
        operation="delete_job_queue",
        op_kwargs={"jobQueue": job_queue},
    )


async def describe_all(
    hub, ctx, job_queues: List = None, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more of your job queues.

    Args:
        job_queues(List, optional): A list of up to 100 queue names or full queue Amazon Resource Name (ARN) entries. Defaults to None.
        max_results(int, optional): The maximum number of results returned by DescribeJobQueues in paginated output. When this parameter is used, DescribeJobQueues only returns maxResults results in a single page and a nextToken response element. The remaining results of the initial request can be seen by sending another DescribeJobQueues request with the returned nextToken value. This value can be between 1 and 100. If this parameter isn't used, then DescribeJobQueues returns up to 100 results and a nextToken value if applicable. Defaults to None.
        next_token(str, optional): The nextToken value returned from a previous paginated DescribeJobQueues request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. This value is null when there are no more results to return.  This token should be treated as an opaque identifier that's only used to retrieve the next items in a list and not for other programmatic purposes. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.batch.job.queue.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.batch.job.queue.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="batch",
        operation="describe_job_queues",
        op_kwargs={
            "jobQueues": job_queues,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    job_queue: str,
    state: str = None,
    priority: int = None,
    compute_environment_order: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a job queue.

    Args:
        job_queue(str): The name or the Amazon Resource Name (ARN) of the job queue.
        state(str, optional): Describes the queue's ability to accept new jobs. If the job queue state is ENABLED, it can accept jobs. If the job queue state is DISABLED, new jobs can't be added to the queue, but jobs already in the queue can finish. Defaults to None.
        priority(int, optional): The priority of the job queue. Job queues with a higher priority (or a higher integer value for the priority parameter) are evaluated first when associated with the same compute environment. Priority is determined in descending order, for example, a job queue with a priority value of 10 is given scheduling preference over a job queue with a priority value of 1. All of the compute environments must be either EC2 (EC2 or SPOT) or Fargate (FARGATE or FARGATE_SPOT). EC2 and Fargate compute environments can't be mixed. Defaults to None.
        compute_environment_order(List, optional): Details the set of compute environments mapped to a job queue and their order relative to each other. This is one of the parameters used by the job scheduler to determine which compute environment should run a given job. Compute environments must be in the VALID state before you can associate them with a job queue. All of the compute environments must be either EC2 (EC2 or SPOT) or Fargate (FARGATE or FARGATE_SPOT). EC2 and Fargate compute environments can't be mixed.  All compute environments that are associated with a job queue must share the same architecture. Batch doesn't support mixing compute environment architecture types in a single job queue. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.batch.job.queue.update(ctx, job_queue=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.batch.job.queue.update job_queue=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="batch",
        operation="update_job_queue",
        op_kwargs={
            "jobQueue": job_queue,
            "state": state,
            "priority": priority,
            "computeEnvironmentOrder": compute_environment_order,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    room_name: str,
    description: str = None,
    profile_arn: str = None,
    provider_calendar_id: str = None,
    client_request_token: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a room with the specified details.

    Args:
        room_name(str): The name for the room.
        description(str, optional): The description for the room. Defaults to None.
        profile_arn(str, optional): The profile ARN for the room. This is required. Defaults to None.
        provider_calendar_id(str, optional): The calendar ARN for the room. Defaults to None.
        client_request_token(str, optional): A unique, user-specified identifier for this request that ensures idempotency. . Defaults to None.
        tags(List, optional): The tags for the room. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.room.init.create(ctx, room_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.room.init.create room_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="create_room",
        op_kwargs={
            "RoomName": room_name,
            "Description": description,
            "ProfileArn": profile_arn,
            "ProviderCalendarId": provider_calendar_id,
            "ClientRequestToken": client_request_token,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, room_arn: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a room by the room ARN.

    Args:
        room_arn(str, optional): The ARN of the room to delete. Required. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.room.init.delete(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.room.init.delete
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="delete_room",
        op_kwargs={"RoomArn": room_arn},
    )


async def get(hub, ctx, room_arn: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets room details by room ARN.

    Args:
        room_arn(str, optional): The ARN of the room for which to request details. Required. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.room.init.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.room.init.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="get_room",
        op_kwargs={"RoomArn": room_arn},
    )


async def resolve(hub, ctx, user_id: str, skill_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Determines the details for the room from which a skill request was invoked. This operation is used by skill developers. To query ResolveRoom from an Alexa skill, the skill ID needs to be authorized. When the skill is using an AWS Lambda function, the skill is automatically authorized when you publish your skill as a private skill to your AWS account. Skills that are hosted using a custom web service must be manually authorized. To get your skill authorized, contact AWS Support with your AWS account ID that queries the ResolveRoom API and skill ID.

    Args:
        user_id(str): The ARN of the user. Required.
        skill_id(str): The ARN of the skill that was requested. Required.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.room.init.resolve(
                ctx, user_id=value, skill_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.room.init.resolve user_id=value, skill_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="resolve_room",
        op_kwargs={"UserId": user_id, "SkillId": skill_id},
    )


async def search(
    hub,
    ctx,
    next_token: str = None,
    max_results: int = None,
    filters: List = None,
    sort_criteria: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Searches rooms and lists the ones that meet a set of filter and sort criteria.

    Args:
        next_token(str, optional): An optional token returned from a prior request. Use this token for pagination of results from this action. If this parameter is specified, the response includes only results beyond the token, up to the value specified by MaxResults. Defaults to None.
        max_results(int, optional): The maximum number of results to include in the response. If more results exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved. . Defaults to None.
        filters(List, optional): The filters to use to list a specified set of rooms. The supported filter keys are RoomName and ProfileName. Defaults to None.
        sort_criteria(List, optional): The sort order to use in listing the specified set of rooms. The supported sort keys are RoomName and ProfileName. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.room.init.search(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.room.init.search
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="search_rooms",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "Filters": filters,
            "SortCriteria": sort_criteria,
        },
    )


async def update(
    hub,
    ctx,
    room_arn: str = None,
    room_name: str = None,
    description: str = None,
    provider_calendar_id: str = None,
    profile_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates room details by room ARN.

    Args:
        room_arn(str, optional): The ARN of the room to update. . Defaults to None.
        room_name(str, optional): The updated name for the room. Defaults to None.
        description(str, optional): The updated description for the room. Defaults to None.
        provider_calendar_id(str, optional): The updated provider calendar ARN for the room. Defaults to None.
        profile_arn(str, optional): The updated profile ARN for the room. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.room.init.update(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.room.init.update
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="update_room",
        op_kwargs={
            "RoomArn": room_arn,
            "RoomName": room_name,
            "Description": description,
            "ProviderCalendarId": provider_calendar_id,
            "ProfileArn": profile_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(hub, ctx, sampling_rule: Dict, tags: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates a rule to control sampling behavior for instrumented applications. Services retrieve rules with GetSamplingRules, and evaluate each rule in ascending order of priority for each request. If a rule matches, the service records a trace, borrowing it from the reservoir size. After 10 seconds, the service reports back to X-Ray with GetSamplingTargets to get updated versions of each in-use rule. The updated rule contains a trace quota that the service can use instead of borrowing from the reservoir.

    Args:
        sampling_rule(Dict): The rule definition.
        tags(List, optional): A map that contains one or more tag keys and tag values to attach to an X-Ray sampling rule. For more information about ways to use tags, see Tagging AWS resources in the AWS General Reference. The following restrictions apply to tags:   Maximum number of user-applied tags per resource: 50   Maximum tag key length: 128 Unicode characters   Maximum tag value length: 256 Unicode characters   Valid values for key and value: a-z, A-Z, 0-9, space, and the following characters: _ . : / = + - and @   Tag keys and values are case sensitive.   Don't use aws: as a prefix for keys; it's reserved for AWS use.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.xray.sampling.rule.create(ctx, sampling_rule=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.xray.sampling.rule.create sampling_rule=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="xray",
        operation="create_sampling_rule",
        op_kwargs={"SamplingRule": sampling_rule, "Tags": tags},
    )


async def delete(hub, ctx, rule_name: str = None, rule_arn: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a sampling rule.

    Args:
        rule_name(str, optional): The name of the sampling rule. Specify a rule by either name or ARN, but not both. Defaults to None.
        rule_arn(str, optional): The ARN of the sampling rule. Specify a rule by either name or ARN, but not both. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.xray.sampling.rule.delete(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.xray.sampling.rule.delete
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="xray",
        operation="delete_sampling_rule",
        op_kwargs={"RuleName": rule_name, "RuleARN": rule_arn},
    )


async def get_all(hub, ctx, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves all sampling rules.

    Args:
        next_token(str, optional): Pagination token. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.xray.sampling.rule.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.xray.sampling.rule.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="xray",
        operation="get_sampling_rules",
        op_kwargs={"NextToken": next_token},
    )


async def update(hub, ctx, sampling_rule_update: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Modifies a sampling rule's configuration.

    Args:
        sampling_rule_update(Dict): The rule and fields to change.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.xray.sampling.rule.update(ctx, sampling_rule_update=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.xray.sampling.rule.update sampling_rule_update=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="xray",
        operation="update_sampling_rule",
        op_kwargs={"SamplingRuleUpdate": sampling_rule_update},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, billing_group_name: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the things you have added to the given billing group.

    Args:
        billing_group_name(str): The name of the billing group.
        next_token(str, optional): To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return per request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.thing.in_.billing_group.list(ctx, billing_group_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.thing.in_.billing_group.list billing_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_things_in_billing_group",
        op_kwargs={
            "billingGroupName": billing_group_name,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def remove(hub, ctx, secret_id: str, remove_replica_regions: List) -> Dict:
    r"""
    **Autogenerated function**

    Remove regions from replication.

    Args:
        secret_id(str): Remove a secret by SecretId from replica Regions.
        remove_replica_regions(List): Remove replication from specific Regions.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.secretsmanager.region_from_replication.remove(
                ctx, secret_id=value, remove_replica_regions=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.secretsmanager.region_from_replication.remove secret_id=value, remove_replica_regions=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="secretsmanager",
        operation="remove_regions_from_replication",
        op_kwargs={
            "SecretId": secret_id,
            "RemoveReplicaRegions": remove_replica_regions,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(
    hub, ctx, directory_arn: str, operations: List, consistency_level: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Performs all the read operations in a batch.

    Args:
        directory_arn(str): The Amazon Resource Name (ARN) that is associated with the Directory. For more information, see arns.
        operations(List): A list of operations that are part of the batch.
        consistency_level(str, optional): Represents the manner and timing in which the successful write or update of an object is reflected in a subsequent read operation of that same object. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.read.batch(
                ctx, directory_arn=value, operations=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.read.batch directory_arn=value, operations=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="batch_read",
        op_kwargs={
            "DirectoryArn": directory_arn,
            "Operations": operations,
            "ConsistencyLevel": consistency_level,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, id_: str, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Fetches the temporarily cached result of an SQL statement. A token is returned to page through the statement results.

    Args:
        id_(str): The identifier of the SQL statement whose results are to be fetched. This value is a universally unique identifier (UUID) generated by Amazon Redshift Data API. A suffix indicates then number of the SQL statement. For example, d9b6c0c9-0747-4bf4-b142-e8883122f766:2 has a suffix of :2 that indicates the second SQL statement of a batch query. This identifier is returned by BatchExecuteStatment, ExecuteStatment, and ListStatements. .
        next_token(str, optional): A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned NextToken value in the next NextToken parameter and retrying the command. If the NextToken field is empty, all response records have been retrieved for the request. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift_data.statement.result.get(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift_data.statement.result.get id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift-data",
        operation="get_statement_result",
        op_kwargs={"Id": id_, "NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disassociate(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates a wireless gateway from its currently associated thing.

    Args:
        id_(str): The ID of the resource to update.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.wireless.gateway.from_.thing.disassociate(
                ctx, id_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.wireless.gateway.from_.thing.disassociate id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="disassociate_wireless_gateway_from_thing",
        op_kwargs={"Id": id_},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(
    hub,
    ctx,
    environment_name: str = None,
    environment_id: str = None,
    attribute_names: List = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves detailed information about the health of instances in your AWS Elastic Beanstalk. This operation requires enhanced health reporting.

    Args:
        environment_name(str, optional): Specify the AWS Elastic Beanstalk environment by name. Defaults to None.
        environment_id(str, optional): Specify the AWS Elastic Beanstalk environment by ID. Defaults to None.
        attribute_names(List, optional): Specifies the response elements you wish to receive. To retrieve all attributes, set to All. If no attribute names are specified, returns a list of instances. Defaults to None.
        next_token(str, optional): Specify the pagination token returned by a previous call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.instance_health.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.instance_health.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="describe_instances_health",
        op_kwargs={
            "EnvironmentName": environment_name,
            "EnvironmentId": environment_id,
            "AttributeNames": attribute_names,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def submit(
    hub,
    ctx,
    cluster: str = None,
    task: str = None,
    container_name: str = None,
    runtime_id: str = None,
    status: str = None,
    exit_code: int = None,
    reason: str = None,
    network_bindings: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

     This action is only used by the Amazon ECS agent, and it is not intended for use outside of the agent.  Sent to acknowledge that a container changed states.

    Args:
        cluster(str, optional): The short name or full ARN of the cluster that hosts the container. Defaults to None.
        task(str, optional): The task ID or full Amazon Resource Name (ARN) of the task that hosts the container. Defaults to None.
        container_name(str, optional): The name of the container. Defaults to None.
        runtime_id(str, optional): The ID of the Docker container. Defaults to None.
        status(str, optional): The status of the state change request. Defaults to None.
        exit_code(int, optional): The exit code returned for the state change request. Defaults to None.
        reason(str, optional): The reason for the state change request. Defaults to None.
        network_bindings(List, optional): The network bindings of the container. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.container.state_change.submit(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.container.state_change.submit
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="submit_container_state_change",
        op_kwargs={
            "cluster": cluster,
            "task": task,
            "containerName": container_name,
            "runtimeId": runtime_id,
            "status": status,
            "exitCode": exit_code,
            "reason": reason,
            "networkBindings": network_bindings,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    destination_cidr_block: str,
    local_gateway_route_table_id: str,
    local_gateway_virtual_interface_group_id: str,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a static route for the specified local gateway route table.

    Args:
        destination_cidr_block(str): The CIDR range used for destination matches. Routing decisions are based on the most specific match.
        local_gateway_route_table_id(str): The ID of the local gateway route table.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        local_gateway_virtual_interface_group_id(str): The ID of the virtual interface group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.local_gateway.route.init.create(
                ctx,
                destination_cidr_block=value,
                local_gateway_route_table_id=value,
                local_gateway_virtual_interface_group_id=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.local_gateway.route.init.create destination_cidr_block=value, local_gateway_route_table_id=value, local_gateway_virtual_interface_group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_local_gateway_route",
        op_kwargs={
            "DestinationCidrBlock": destination_cidr_block,
            "LocalGatewayRouteTableId": local_gateway_route_table_id,
            "DryRun": dry_run,
            "LocalGatewayVirtualInterfaceGroupId": local_gateway_virtual_interface_group_id,
        },
    )


async def delete(
    hub,
    ctx,
    destination_cidr_block: str,
    local_gateway_route_table_id: str,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified route from the specified local gateway route table.

    Args:
        destination_cidr_block(str): The CIDR range for the route. This must match the CIDR for the route exactly.
        local_gateway_route_table_id(str): The ID of the local gateway route table.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.local_gateway.route.init.delete(
                ctx, destination_cidr_block=value, local_gateway_route_table_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.local_gateway.route.init.delete destination_cidr_block=value, local_gateway_route_table_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_local_gateway_route",
        op_kwargs={
            "DestinationCidrBlock": destination_cidr_block,
            "LocalGatewayRouteTableId": local_gateway_route_table_id,
            "DryRun": dry_run,
        },
    )


async def search(
    hub,
    ctx,
    local_gateway_route_table_id: str,
    filters: List,
    max_results: int = None,
    next_token: str = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Searches for routes in the specified local gateway route table.

    Args:
        local_gateway_route_table_id(str): The ID of the local gateway route table.
        filters(List): One or more filters.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.local_gateway.route.init.search(
                ctx, local_gateway_route_table_id=value, filters=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.local_gateway.route.init.search local_gateway_route_table_id=value, filters=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="search_local_gateway_routes",
        op_kwargs={
            "LocalGatewayRouteTableId": local_gateway_route_table_id,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    service: str,
    account_id: str = None,
    filter_: Dict = None,
    account_scope: str = None,
    lookback_period_in_days: str = None,
    term_in_years: str = None,
    payment_option: str = None,
    service_specification: Dict = None,
    page_size: int = None,
    next_page_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets recommendations for which reservations to purchase. These recommendations could help you reduce your costs. Reservations provide a discounted hourly rate (up to 75%) compared to On-Demand pricing. AWS generates your recommendations by identifying your On-Demand usage during a specific time period and collecting your usage into categories that are eligible for a reservation. After AWS has these categories, it simulates every combination of reservations in each category of usage to identify the best number of each type of RI to purchase to maximize your estimated savings.  For example, AWS automatically aggregates your Amazon EC2 Linux, shared tenancy, and c4 family usage in the US West (Oregon) Region and recommends that you buy size-flexible regional reservations to apply to the c4 family usage. AWS recommends the smallest size instance in an instance family. This makes it easier to purchase a size-flexible RI. AWS also shows the equal number of normalized units so that you can purchase any instance size that you want. For this example, your RI recommendation would be for c4.large because that is the smallest size instance in the c4 instance family.

    Args:
        account_id(str, optional): The account ID that is associated with the recommendation. . Defaults to None.
        service(str): The specific service that you want recommendations for.
        filter_(Dict, optional): Use Expression to filter by cost or by usage. There are two patterns:    Simple dimension values - You can set the dimension name and values for the filters that you plan to use. For example, you can filter for REGION==us-east-1 OR REGION==us-west-1. For GetRightsizingRecommendation, the Region is a full name (for example, REGION==US East (N. Virginia). The Expression example looks like:  { "Dimensions": { "Key": "REGION", "Values": [ "us-east-1", “us-west-1” ] } }  The list of dimension values are OR'd together to retrieve cost or usage data. You can create Expression and DimensionValues objects using either with* methods or set* methods in multiple lines.    Compound dimension values with logical operations - You can use multiple Expression types and the logical operators AND/OR/NOT to create a list of one or more Expression objects. This allows you to filter on more advanced options. For example, you can filter on ((REGION == us-east-1 OR REGION == us-west-1) OR (TAG.Type == Type1)) AND (USAGE_TYPE != DataTransfer). The Expression for that looks like this:  { "And": [ {"Or": [ {"Dimensions": { "Key": "REGION", "Values": [ "us-east-1", "us-west-1" ] }}, {"Tags": { "Key": "TagName", "Values": ["Value1"] } } ]}, {"Not": {"Dimensions": { "Key": "USAGE_TYPE", "Values": ["DataTransfer"] }}} ] }    Because each Expression can have only one operator, the service returns an error if more than one is specified. The following example shows an Expression object that creates an error.    { "And": [ ... ], "DimensionValues": { "Dimension": "USAGE_TYPE", "Values": [ "DataTransfer" ] } }      For the GetRightsizingRecommendation action, a combination of OR and NOT is not supported. OR is not supported between different dimensions, or dimensions and tags. NOT operators aren't supported. Dimensions are also limited to LINKED_ACCOUNT, REGION, or RIGHTSIZING_TYPE. For the GetReservationPurchaseRecommendation action, only NOT is supported. AND and OR are not supported. Dimensions are limited to LINKED_ACCOUNT. . Defaults to None.
        account_scope(str, optional): The account scope that you want your recommendations for. Amazon Web Services calculates recommendations including the management account and member accounts if the value is set to PAYER. If the value is LINKED, recommendations are calculated for individual member accounts only. Defaults to None.
        lookback_period_in_days(str, optional): The number of previous days that you want AWS to consider when it calculates your recommendations. Defaults to None.
        term_in_years(str, optional): The reservation term that you want recommendations for. Defaults to None.
        payment_option(str, optional): The reservation purchase option that you want recommendations for. Defaults to None.
        service_specification(Dict, optional): The hardware specifications for the service instances that you want recommendations for, such as standard or convertible Amazon EC2 instances. Defaults to None.
        page_size(int, optional): The number of recommendations that you want returned in a single response object. Defaults to None.
        next_page_token(str, optional): The pagination token that indicates the next set of results that you want to retrieve. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ce.reservation.purchase_recommendation.get(ctx, service=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ce.reservation.purchase_recommendation.get service=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ce",
        operation="get_reservation_purchase_recommendation",
        op_kwargs={
            "AccountId": account_id,
            "Service": service,
            "Filter": filter_,
            "AccountScope": account_scope,
            "LookbackPeriodInDays": lookback_period_in_days,
            "TermInYears": term_in_years,
            "PaymentOption": payment_option,
            "ServiceSpecification": service_specification,
            "PageSize": page_size,
            "NextPageToken": next_page_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    relational_database_name: str,
    relational_database_snapshot_name: str,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a snapshot of your database in Amazon Lightsail. You can use snapshots for backups, to make copies of a database, and to save data before deleting a database. The create relational database snapshot operation supports tag-based access control via request tags. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        relational_database_name(str): The name of the database on which to base your new snapshot.
        relational_database_snapshot_name(str): The name for your new database snapshot. Constraints:   Must contain from 2 to 255 alphanumeric characters, or hyphens.   The first and last character must be a letter or number.  .
        tags(List, optional): The tag keys and optional values to add to the resource during create. Use the TagResource action to tag a resource after it's created. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.relational_database.snapshot.create(
                ctx, relational_database_name=value, relational_database_snapshot_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.relational_database.snapshot.create relational_database_name=value, relational_database_snapshot_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="create_relational_database_snapshot",
        op_kwargs={
            "relationalDatabaseName": relational_database_name,
            "relationalDatabaseSnapshotName": relational_database_snapshot_name,
            "tags": tags,
        },
    )


async def delete(hub, ctx, relational_database_snapshot_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a database snapshot in Amazon Lightsail. The delete relational database snapshot operation supports tag-based access control via resource tags applied to the resource identified by relationalDatabaseName. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        relational_database_snapshot_name(str): The name of the database snapshot that you are deleting.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.relational_database.snapshot.delete(
                ctx, relational_database_snapshot_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.relational_database.snapshot.delete relational_database_snapshot_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="delete_relational_database_snapshot",
        op_kwargs={"relationalDatabaseSnapshotName": relational_database_snapshot_name},
    )


async def get(hub, ctx, relational_database_snapshot_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a specific database snapshot in Amazon Lightsail.

    Args:
        relational_database_snapshot_name(str): The name of the database snapshot for which to get information.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.relational_database.snapshot.get(
                ctx, relational_database_snapshot_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.relational_database.snapshot.get relational_database_snapshot_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_relational_database_snapshot",
        op_kwargs={"relationalDatabaseSnapshotName": relational_database_snapshot_name},
    )


async def get_all(hub, ctx, page_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about all of your database snapshots in Amazon Lightsail.

    Args:
        page_token(str, optional): The token to advance to the next page of results from your request. To get a page token, perform an initial GetRelationalDatabaseSnapshots request. If your results are paginated, the response will return a next page token that you can specify as the page token in a subsequent request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.relational_database.snapshot.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.relational_database.snapshot.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_relational_database_snapshots",
        op_kwargs={"pageToken": page_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, configuration_recorder_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the configuration recorder. After the configuration recorder is deleted, AWS Config will not record resource configuration changes until you create a new configuration recorder. This action does not delete the configuration information that was previously recorded. You will be able to access the previously recorded information by using the GetResourceConfigHistory action, but you will not be able to access this information in the AWS Config console until you create a new configuration recorder.

    Args:
        configuration_recorder_name(str): The name of the configuration recorder to be deleted. You can retrieve the name of your configuration recorder by using the DescribeConfigurationRecorders action.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.configuration.recorder.init.delete(
                ctx, configuration_recorder_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.configuration.recorder.init.delete configuration_recorder_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="delete_configuration_recorder",
        op_kwargs={"ConfigurationRecorderName": configuration_recorder_name},
    )


async def describe_all(hub, ctx, configuration_recorder_names: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the details for the specified configuration recorders. If the configuration recorder is not specified, this action returns the details for all configuration recorders associated with the account.  Currently, you can specify only one configuration recorder per region in your account.

    Args:
        configuration_recorder_names(List, optional): A list of configuration recorder names. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.configuration.recorder.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.configuration.recorder.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="describe_configuration_recorders",
        op_kwargs={"ConfigurationRecorderNames": configuration_recorder_names},
    )


async def put(hub, ctx, configuration_recorder: Dict) -> None:
    r"""
    **Autogenerated function**

    Creates a new configuration recorder to record the selected resource configurations. You can use this action to change the role roleARN or the recordingGroup of an existing recorder. To change the role, call the action on the existing configuration recorder and specify a role.  Currently, you can specify only one configuration recorder per region in your account. If ConfigurationRecorder does not have the recordingGroup parameter specified, the default is to record all supported resource types.

    Args:
        configuration_recorder(Dict): The configuration recorder object that records each configuration change made to the resources.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.configuration.recorder.init.put(
                ctx, configuration_recorder=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.configuration.recorder.init.put configuration_recorder=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="put_configuration_recorder",
        op_kwargs={"ConfigurationRecorder": configuration_recorder},
    )


async def start(hub, ctx, configuration_recorder_name: str) -> None:
    r"""
    **Autogenerated function**

    Starts recording configurations of the AWS resources you have selected to record in your AWS account. You must have created at least one delivery channel to successfully start the configuration recorder.

    Args:
        configuration_recorder_name(str): The name of the recorder object that records each configuration change made to the resources.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.configuration.recorder.init.start(
                ctx, configuration_recorder_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.configuration.recorder.init.start configuration_recorder_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="start_configuration_recorder",
        op_kwargs={"ConfigurationRecorderName": configuration_recorder_name},
    )


async def stop(hub, ctx, configuration_recorder_name: str) -> None:
    r"""
    **Autogenerated function**

    Stops recording configurations of the AWS resources you have selected to record in your AWS account.

    Args:
        configuration_recorder_name(str): The name of the recorder object that records each configuration change made to the resources.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.configuration.recorder.init.stop(
                ctx, configuration_recorder_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.configuration.recorder.init.stop configuration_recorder_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="stop_configuration_recorder",
        op_kwargs={"ConfigurationRecorderName": configuration_recorder_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub,
    ctx,
    comment_id: str,
    reaction_user_arn: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about reactions to a specified comment ID. Reactions from users who have been deleted will not be included in the count.

    Args:
        comment_id(str): The ID of the comment for which you want to get reactions information.
        reaction_user_arn(str, optional): Optional. The Amazon Resource Name (ARN) of the user or identity for which you want to get reaction information. Defaults to None.
        next_token(str, optional): An enumeration token that, when provided in a request, returns the next batch of the results. . Defaults to None.
        max_results(int, optional): A non-zero, non-negative integer used to limit the number of returned results. The default is the same as the allowed maximum, 1,000. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.comment.reaction.get_all(ctx, comment_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.comment.reaction.get_all comment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="get_comment_reactions",
        op_kwargs={
            "commentId": comment_id,
            "reactionUserArn": reaction_user_arn,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )


async def put(hub, ctx, comment_id: str, reaction_value: str) -> None:
    r"""
    **Autogenerated function**

    Adds or updates a reaction to a specified comment for the user whose identity is used to make the request. You can only add or update a reaction for yourself. You cannot add, modify, or delete a reaction for another user.

    Args:
        comment_id(str): The ID of the comment to which you want to add or update a reaction.
        reaction_value(str): The emoji reaction you want to add or update. To remove a reaction, provide a value of blank or null. You can also provide the value of none. For information about emoji reaction values supported in AWS CodeCommit, see the AWS CodeCommit User Guide.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.comment.reaction.put(
                ctx, comment_id=value, reaction_value=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.comment.reaction.put comment_id=value, reaction_value=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="put_comment_reaction",
        op_kwargs={"commentId": comment_id, "reactionValue": reaction_value},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disable(hub, ctx, directory_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Disables multi-factor authentication (MFA) with the Remote Authentication Dial In User Service (RADIUS) server for an AD Connector or Microsoft AD directory.

    Args:
        directory_id(str): The identifier of the directory for which to disable MFA.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.radius.disable(ctx, directory_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.radius.disable directory_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="disable_radius",
        op_kwargs={"DirectoryId": directory_id},
    )


async def enable(hub, ctx, directory_id: str, radius_settings: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Enables multi-factor authentication (MFA) with the Remote Authentication Dial In User Service (RADIUS) server for an AD Connector or Microsoft AD directory.

    Args:
        directory_id(str): The identifier of the directory for which to enable MFA.
        radius_settings(Dict): A RadiusSettings object that contains information about the RADIUS server.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.radius.enable(ctx, directory_id=value, radius_settings=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.radius.enable directory_id=value, radius_settings=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="enable_radius",
        op_kwargs={"DirectoryId": directory_id, "RadiusSettings": radius_settings},
    )


async def update(hub, ctx, directory_id: str, radius_settings: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Updates the Remote Authentication Dial In User Service (RADIUS) server information for an AD Connector or Microsoft AD directory.

    Args:
        directory_id(str): The identifier of the directory for which to update the RADIUS server information.
        radius_settings(Dict): A RadiusSettings object that contains information about the RADIUS server.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.radius.update(ctx, directory_id=value, radius_settings=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.radius.update directory_id=value, radius_settings=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="update_radius",
        op_kwargs={"DirectoryId": directory_id, "RadiusSettings": radius_settings},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(hub, ctx, resource_id: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Creates the specified tags for the specified WorkSpaces resource.

    Args:
        resource_id(str): The identifier of the WorkSpaces resource. The supported resource types are WorkSpaces, registered directories, images, custom bundles, IP access control groups, and connection aliases.
        tags(List): The tags. Each WorkSpaces resource can have a maximum of 50 tags.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.tags.create(ctx, resource_id=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.tags.create resource_id=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="create_tags",
        op_kwargs={"ResourceId": resource_id, "Tags": tags},
    )


async def delete(hub, ctx, resource_id: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified tags from the specified WorkSpaces resource.

    Args:
        resource_id(str): The identifier of the WorkSpaces resource. The supported resource types are WorkSpaces, registered directories, images, custom bundles, IP access control groups, and connection aliases.
        tag_keys(List): The tag keys.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.tags.delete(ctx, resource_id=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.tags.delete resource_id=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="delete_tags",
        op_kwargs={"ResourceId": resource_id, "TagKeys": tag_keys},
    )


async def describe(hub, ctx, resource_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified tags for the specified WorkSpaces resource.

    Args:
        resource_id(str): The identifier of the WorkSpaces resource. The supported resource types are WorkSpaces, registered directories, images, custom bundles, IP access control groups, and connection aliases.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.tags.describe(ctx, resource_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.tags.describe resource_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="describe_tags",
        op_kwargs={"ResourceId": resource_id},
    )
